function B = sort_locale(A, locale)
% B = SORT_LOCALE(A) sorts cell array of character verctors or string
% array in alphabetical order using czech locale. The shape of array A must
% be row or column vector.
%
% B = SORT_LOCALE(A,locale)
% Call SORT_LOCALE with a second input argument in order to specify
% a different locale, where locale must be a cell array
% with two character vectors, 'language' and 'territory':
% locale = {'language', 'territory'}
%
% EXAMPLE
% S = sort_locale({'zelí','mrkev','česnek','petržel','řepa'})
% S = sort_locale({'zelí','mrkev','česnek','petržel','řepa'},{'cs', 'CZ'})

sz = size(A); % remember the shape of the input vector
if verLessThan('matlab','9.1')
    % An older version of MATLAB doesn't include required version of java.
    error('This function runs properly in MATLAB R2016b and newer.')
    % An older version of MATLAB doesn't include string array data type and
    % function isstring.
    % validateattributes(A, {'cell'},{'vector'})
    % stringID = 0;
else
    % If the input A is a string array, convert A to
    % cell arrays of character vectors:
    validateattributes(A, {'string','cell'},{'vector'})
    stringID = isstring(A);
    if stringID
        A = cellstr(A);
    end
end

if nargin == 1
    locale = {'cs', 'CZ'};
end
validateattributes(locale,{'cell'},{'numel',2})

% ------------Java------------
% Create a Collator Java object with czech locale:
coll = java.text.Collator.getInstance(java.util.Locale(locale{:}));
% Pass MATLAB data to Java object list:
list = java.util.Arrays.asList(A);
% Sort list using the Collator coll:
java.util.Collections.sort(list, coll);

% Convert sorted Java object list to MATLAB cell array of character
% vectors:
s = size(list);
B = cell(1,s);
for i=1:size(list)
    B{i}=list.get(i-1);
end
% ----------------------------

% If the input A is a string array, convert sorted cell array B
% to a string array:
if stringID
    B = string(B);
end
B = reshape(B,sz);
